@@ -2,7 +2,7 @@
 
 from __future__ import annotations
 
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Any
 
 from .version import __version__
 
@@ -10,7 +10,7 @@ if TYPE_CHECKING:
     from sphinx.application import Sphinx
 
 
-def setup(app: Sphinx) -> None:
+def setup(app: Sphinx) -> dict[str, Any]:
     app.add_css_file("custom.css")
 
     from ._logic import SphinxArgparseCli
@@ -18,6 +18,8 @@ def setup(app: Sphinx) -> None:
     app.add_directive(SphinxArgparseCli.name, SphinxArgparseCli)
     app.add_config_value("sphinx_argparse_cli_prefix_document", False, "env")  # noqa: FBT003
 
+    return {"parallel_read_safe": True}
+
 
 __all__ = [
     "__version__",
